@@ -2,11 +2,12 @@
 Core module containing the main agent components.
 """
 
-from .agent_runner import AgentRunner
+from .agent_runner import AgentRunner, AgentConfiguration
 from .model import ToolCall, ToolError, ToolNotFound
 
 __all__ = [
     "AgentRunner",
+    "AgentConfiguration",
     "ToolCall",
     "ToolError",
     "ToolNotFound",
